@@ -1,7 +1,10 @@
 from tempfile import TemporaryDirectory
 import os 
+from functools import partial
 
 from forest.common import proc_utils
+from forest.common.parser import make_regrex_pattern
+
 
 cmake_command = 'cmake'
 default_args = list()
@@ -34,7 +37,10 @@ def _build(self, target, jobs):
 def _call_cmake(args, cwd='.', print_on_error=True):
 
     args_str = list(map(str, args))
-    return proc_utils.call_process(args=[cmake_command] + args_str, cwd=cwd, print_on_error=print_on_error)
+    return proc_utils.call_process(args=[cmake_command] + args_str,
+                                   cwd=cwd, 
+                                   print_on_error=print_on_error,
+                                   update_regrex_pattern=make_regrex_pattern)
 
 
 def _find_package(pkg_name: str):
